@@ -1,12 +1,7 @@
 package SmokeRunner::Multi;
-BEGIN {
-  $SmokeRunner::Multi::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Manage smoke tests across multiple branches/checkouts/projects
-
+$SmokeRunner::Multi::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -100,13 +95,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi - Manage smoke tests across multiple branches/checkouts/projects
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
