@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::DBI;
-BEGIN {
-  $SmokeRunner::Multi::DBI::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::DBI::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: DBI helpers for SmokeRunner::Multi
-
+$SmokeRunner::Multi::DBI::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -61,13 +56,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::DBI - DBI helpers for SmokeRunner::Multi
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
