@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::Reporter::Screen;
-BEGIN {
-  $SmokeRunner::Multi::Reporter::Screen::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::Reporter::Screen::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Prints runner output to STDOUT
-
+$SmokeRunner::Multi::Reporter::Screen::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -31,13 +26,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::Reporter::Screen - Prints runner output to STDOUT
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
