@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::Reporter::Smolder;
-BEGIN {
-  $SmokeRunner::Multi::Reporter::Smolder::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::Reporter::Smolder::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT:  Reports test runs to a Smolder installation
-
+$SmokeRunner::Multi::Reporter::Smolder::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -26,6 +21,7 @@ sub new
 
     my $self = $class->SUPER::new(@_);
 
+    $DB::single = 1;
     my $smolder_config = SmokeRunner::Multi::Config->instance()->smolder();
 
     for my $k (@SmolderKeys)
@@ -78,13 +74,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::Reporter::Smolder - Reports test runs to a Smolder installation
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
