@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::Runner;
-BEGIN {
-  $SmokeRunner::Multi::Runner::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::Runner::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Base class for running test sets
-
+$SmokeRunner::Multi::Runner::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -40,13 +35,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::Runner - Base class for running test sets
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
