@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::Runner::TAPArchive;
-BEGIN {
-  $SmokeRunner::Multi::Runner::TAPArchive::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::Runner::TAPArchive::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Runner subclass which creates a TAP archive file
-
+$SmokeRunner::Multi::Runner::TAPArchive::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -105,13 +100,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::Runner::TAPArchive - Runner subclass which creates a TAP archive file
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
