@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::TestSet;
-BEGIN {
-  $SmokeRunner::Multi::TestSet::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::TestSet::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Represents a set of tests
-
+$SmokeRunner::Multi::TestSet::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -217,13 +212,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::TestSet - Represents a set of tests
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
