@@ -1,12 +1,7 @@
 package SmokeRunner::Multi::Validate;
-BEGIN {
-  $SmokeRunner::Multi::Validate::AUTHORITY = 'cpan:YANICK';
-}
-{
-  $SmokeRunner::Multi::Validate::VERSION = '0.19';
-}
+our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Wrapper around Params::Validate for SmokeRunner::Multi
-
+$SmokeRunner::Multi::Validate::VERSION = '0.20';
 use strict;
 use warnings;
 
@@ -88,13 +83,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SmokeRunner::Multi::Validate - Wrapper around Params::Validate for SmokeRunner::Multi
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
